# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class CreateMonitorGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'CreateMonitorGroup','cms')
		self.set_method('POST')

	def get_ContactGroups(self):
		return self.get_query_params().get('ContactGroups')

	def set_ContactGroups(self,ContactGroups):
		self.add_query_param('ContactGroups',ContactGroups)

	def get_GroupName(self):
		return self.get_query_params().get('GroupName')

	def set_GroupName(self,GroupName):
		self.add_query_param('GroupName',GroupName)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutLogMonitorRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutLogMonitor','cms')
		self.set_method('POST')

	def get_SlsLogstore(self):
		return self.get_query_params().get('SlsLogstore')

	def set_SlsLogstore(self,SlsLogstore):
		self.add_query_param('SlsLogstore',SlsLogstore)

	def get_SlsProject(self):
		return self.get_query_params().get('SlsProject')

	def set_SlsProject(self,SlsProject):
		self.add_query_param('SlsProject',SlsProject)

	def get_ValueFilters(self):
		return self.get_query_params().get('ValueFilter')

	def set_ValueFilters(self, ValueFilters):
		for depth1 in range(len(ValueFilters)):
			if ValueFilters[depth1].get('Value') is not None:
				self.add_query_param('ValueFilter.' + str(depth1 + 1) + '.Value', ValueFilters[depth1].get('Value'))
			if ValueFilters[depth1].get('Key') is not None:
				self.add_query_param('ValueFilter.' + str(depth1 + 1) + '.Key', ValueFilters[depth1].get('Key'))
			if ValueFilters[depth1].get('Operator') is not None:
				self.add_query_param('ValueFilter.' + str(depth1 + 1) + '.Operator', ValueFilters[depth1].get('Operator'))

	def get_MetricExpress(self):
		return self.get_query_params().get('MetricExpress')

	def set_MetricExpress(self,MetricExpress):
		self.add_query_param('MetricExpress',MetricExpress)

	def get_SlsRegionId(self):
		return self.get_query_params().get('SlsRegionId')

	def set_SlsRegionId(self,SlsRegionId):
		self.add_query_param('SlsRegionId',SlsRegionId)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_Tumblingwindows(self):
		return self.get_query_params().get('Tumblingwindows')

	def set_Tumblingwindows(self,Tumblingwindows):
		self.add_query_param('Tumblingwindows',Tumblingwindows)

	def get_ValueFilterRelation(self):
		return self.get_query_params().get('ValueFilterRelation')

	def set_ValueFilterRelation(self,ValueFilterRelation):
		self.add_query_param('ValueFilterRelation',ValueFilterRelation)

	def get_Unit(self):
		return self.get_query_params().get('Unit')

	def set_Unit(self,Unit):
		self.add_query_param('Unit',Unit)

	def get_Groupbyss(self):
		return self.get_query_params().get('Groupbys')

	def set_Groupbyss(self, Groupbyss):
		for depth1 in range(len(Groupbyss)):
			if Groupbyss[depth1].get('FieldName') is not None:
				self.add_query_param('Groupbys.' + str(depth1 + 1) + '.FieldName', Groupbyss[depth1].get('FieldName'))
			if Groupbyss[depth1].get('Alias') is not None:
				self.add_query_param('Groupbys.' + str(depth1 + 1) + '.Alias', Groupbyss[depth1].get('Alias'))

	def get_LogId(self):
		return self.get_query_params().get('LogId')

	def set_LogId(self,LogId):
		self.add_query_param('LogId',LogId)

	def get_Aggregatess(self):
		return self.get_query_params().get('Aggregates')

	def set_Aggregatess(self, Aggregatess):
		for depth1 in range(len(Aggregatess)):
			if Aggregatess[depth1].get('FieldName') is not None:
				self.add_query_param('Aggregates.' + str(depth1 + 1) + '.FieldName', Aggregatess[depth1].get('FieldName'))
			if Aggregatess[depth1].get('Function') is not None:
				self.add_query_param('Aggregates.' + str(depth1 + 1) + '.Function', Aggregatess[depth1].get('Function'))
			if Aggregatess[depth1].get('Alias') is not None:
				self.add_query_param('Aggregates.' + str(depth1 + 1) + '.Alias', Aggregatess[depth1].get('Alias'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutCustomMetricRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutCustomMetric','cms')
		self.set_method('POST')

	def get_MetricLists(self):
		return self.get_query_params().get('MetricList')

	def set_MetricLists(self, MetricLists):
		for depth1 in range(len(MetricLists)):
			if MetricLists[depth1].get('Period') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.Period', MetricLists[depth1].get('Period'))
			if MetricLists[depth1].get('GroupId') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.GroupId', MetricLists[depth1].get('GroupId'))
			if MetricLists[depth1].get('Values') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.Values', MetricLists[depth1].get('Values'))
			if MetricLists[depth1].get('Time') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.Time', MetricLists[depth1].get('Time'))
			if MetricLists[depth1].get('MetricName') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.MetricName', MetricLists[depth1].get('MetricName'))
			if MetricLists[depth1].get('Type') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.Type', MetricLists[depth1].get('Type'))
			if MetricLists[depth1].get('Dimensions') is not None:
				self.add_query_param('MetricList.' + str(depth1 + 1) + '.Dimensions', MetricLists[depth1].get('Dimensions'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class ModifyMetricRuleTemplateRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'ModifyMetricRuleTemplate','cms')
		self.set_method('POST')

	def get_RestVersion(self):
		return self.get_query_params().get('RestVersion')

	def set_RestVersion(self,RestVersion):
		self.add_query_param('RestVersion',RestVersion)

	def get_Description(self):
		return self.get_query_params().get('Description')

	def set_Description(self,Description):
		self.add_query_param('Description',Description)

	def get_TemplateId(self):
		return self.get_query_params().get('TemplateId')

	def set_TemplateId(self,TemplateId):
		self.add_query_param('TemplateId',TemplateId)

	def get_Name(self):
		return self.get_query_params().get('Name')

	def set_Name(self,Name):
		self.add_query_param('Name',Name)

	def get_AlertTemplatess(self):
		return self.get_query_params().get('AlertTemplates')

	def set_AlertTemplatess(self, AlertTemplatess):
		for depth1 in range(len(AlertTemplatess)):
			if AlertTemplatess[depth1].get('Period') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Period', AlertTemplatess[depth1].get('Period'))
			if AlertTemplatess[depth1].get('Escalations.Warn.Threshold') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Warn.Threshold', AlertTemplatess[depth1].get('Escalations.Warn.Threshold'))
			if AlertTemplatess[depth1].get('Webhook') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Webhook', AlertTemplatess[depth1].get('Webhook'))
			if AlertTemplatess[depth1].get('Escalations.Warn.ComparisonOperator') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Warn.ComparisonOperator', AlertTemplatess[depth1].get('Escalations.Warn.ComparisonOperator'))
			if AlertTemplatess[depth1].get('Escalations.Critical.Statistics') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Critical.Statistics', AlertTemplatess[depth1].get('Escalations.Critical.Statistics'))
			if AlertTemplatess[depth1].get('Escalations.Info.Times') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Info.Times', AlertTemplatess[depth1].get('Escalations.Info.Times'))
			if AlertTemplatess[depth1].get('RuleName') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.RuleName', AlertTemplatess[depth1].get('RuleName'))
			if AlertTemplatess[depth1].get('Escalations.Info.Statistics') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Info.Statistics', AlertTemplatess[depth1].get('Escalations.Info.Statistics'))
			if AlertTemplatess[depth1].get('Escalations.Critical.Times') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Critical.Times', AlertTemplatess[depth1].get('Escalations.Critical.Times'))
			if AlertTemplatess[depth1].get('Escalations.Info.ComparisonOperator') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Info.ComparisonOperator', AlertTemplatess[depth1].get('Escalations.Info.ComparisonOperator'))
			if AlertTemplatess[depth1].get('Escalations.Warn.Statistics') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Warn.Statistics', AlertTemplatess[depth1].get('Escalations.Warn.Statistics'))
			if AlertTemplatess[depth1].get('Escalations.Info.Threshold') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Info.Threshold', AlertTemplatess[depth1].get('Escalations.Info.Threshold'))
			if AlertTemplatess[depth1].get('Namespace') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Namespace', AlertTemplatess[depth1].get('Namespace'))
			if AlertTemplatess[depth1].get('Selector') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Selector', AlertTemplatess[depth1].get('Selector'))
			if AlertTemplatess[depth1].get('MetricName') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.MetricName', AlertTemplatess[depth1].get('MetricName'))
			if AlertTemplatess[depth1].get('Category') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Category', AlertTemplatess[depth1].get('Category'))
			if AlertTemplatess[depth1].get('Escalations.Critical.ComparisonOperator') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Critical.ComparisonOperator', AlertTemplatess[depth1].get('Escalations.Critical.ComparisonOperator'))
			if AlertTemplatess[depth1].get('Escalations.Warn.Times') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Warn.Times', AlertTemplatess[depth1].get('Escalations.Warn.Times'))
			if AlertTemplatess[depth1].get('Escalations.Critical.Threshold') is not None:
				self.add_query_param('AlertTemplates.' + str(depth1 + 1) + '.Escalations.Critical.Threshold', AlertTemplatess[depth1].get('Escalations.Critical.Threshold'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class CreateDynamicTagGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'CreateDynamicTagGroup','cms')
		self.set_method('POST')

	def get_EnableSubscribeEvent(self):
		return self.get_query_params().get('EnableSubscribeEvent')

	def set_EnableSubscribeEvent(self,EnableSubscribeEvent):
		self.add_query_param('EnableSubscribeEvent',EnableSubscribeEvent)

	def get_MatchExpressFilterRelation(self):
		return self.get_query_params().get('MatchExpressFilterRelation')

	def set_MatchExpressFilterRelation(self,MatchExpressFilterRelation):
		self.add_query_param('MatchExpressFilterRelation',MatchExpressFilterRelation)

	def get_EnableInstallAgent(self):
		return self.get_query_params().get('EnableInstallAgent')

	def set_EnableInstallAgent(self,EnableInstallAgent):
		self.add_query_param('EnableInstallAgent',EnableInstallAgent)

	def get_MatchExpresss(self):
		return self.get_query_params().get('MatchExpress')

	def set_MatchExpresss(self, MatchExpresss):
		for depth1 in range(len(MatchExpresss)):
			if MatchExpresss[depth1].get('TagValue') is not None:
				self.add_query_param('MatchExpress.' + str(depth1 + 1) + '.TagValue', MatchExpresss[depth1].get('TagValue'))
			if MatchExpresss[depth1].get('TagValueMatchFunction') is not None:
				self.add_query_param('MatchExpress.' + str(depth1 + 1) + '.TagValueMatchFunction', MatchExpresss[depth1].get('TagValueMatchFunction'))

	def get_ContactGroupLists(self):
		return self.get_query_params().get('ContactGroupList')

	def set_ContactGroupLists(self, ContactGroupLists):
		for depth1 in range(len(ContactGroupLists)):
			if ContactGroupLists[depth1] is not None:
				self.add_query_param('ContactGroupList.' + str(depth1 + 1) , ContactGroupLists[depth1])

	def get_TemplateIdLists(self):
		return self.get_query_params().get('TemplateIdList')

	def set_TemplateIdLists(self, TemplateIdLists):
		for depth1 in range(len(TemplateIdLists)):
			if TemplateIdLists[depth1] is not None:
				self.add_query_param('TemplateIdList.' + str(depth1 + 1) , TemplateIdLists[depth1])

	def get_TagKey(self):
		return self.get_query_params().get('TagKey')

	def set_TagKey(self,TagKey):
		self.add_query_param('TagKey',TagKey)

	def get_TagRegionId(self):
		return self.get_query_params().get('TagRegionId')

	def set_TagRegionId(self,TagRegionId):
		self.add_query_param('TagRegionId',TagRegionId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutContactRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutContact','cms')
		self.set_method('POST')

	def get_ChannelsDingWebHook(self):
		return self.get_query_params().get('Channels.DingWebHook')

	def set_ChannelsDingWebHook(self,ChannelsDingWebHook):
		self.add_query_param('Channels.DingWebHook',ChannelsDingWebHook)

	def get_ContactName(self):
		return self.get_query_params().get('ContactName')

	def set_ContactName(self,ContactName):
		self.add_query_param('ContactName',ContactName)

	def get_ChannelsMail(self):
		return self.get_query_params().get('Channels.Mail')

	def set_ChannelsMail(self,ChannelsMail):
		self.add_query_param('Channels.Mail',ChannelsMail)

	def get_ChannelsAliIM(self):
		return self.get_query_params().get('Channels.AliIM')

	def set_ChannelsAliIM(self,ChannelsAliIM):
		self.add_query_param('Channels.AliIM',ChannelsAliIM)

	def get_Describe(self):
		return self.get_query_params().get('Describe')

	def set_Describe(self,Describe):
		self.add_query_param('Describe',Describe)

	def get_Lang(self):
		return self.get_query_params().get('Lang')

	def set_Lang(self,Lang):
		self.add_query_param('Lang',Lang)

	def get_ChannelsSMS(self):
		return self.get_query_params().get('Channels.SMS')

	def set_ChannelsSMS(self,ChannelsSMS):
		self.add_query_param('Channels.SMS',ChannelsSMS)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeMonitoringAgentHostsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMonitoringAgentHosts','cms')
		self.set_method('POST')

	def get_SerialNumbers(self):
		return self.get_query_params().get('SerialNumbers')

	def set_SerialNumbers(self,SerialNumbers):
		self.add_query_param('SerialNumbers',SerialNumbers)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_HostName(self):
		return self.get_query_params().get('HostName')

	def set_HostName(self,HostName):
		self.add_query_param('HostName',HostName)

	def get_InstanceRegionId(self):
		return self.get_query_params().get('InstanceRegionId')

	def set_InstanceRegionId(self,InstanceRegionId):
		self.add_query_param('InstanceRegionId',InstanceRegionId)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_AliyunHost(self):
		return self.get_query_params().get('AliyunHost')

	def set_AliyunHost(self,AliyunHost):
		self.add_query_param('AliyunHost',AliyunHost)

	def get_KeyWord(self):
		return self.get_query_params().get('KeyWord')

	def set_KeyWord(self,KeyWord):
		self.add_query_param('KeyWord',KeyWord)

	def get_InstanceIds(self):
		return self.get_query_params().get('InstanceIds')

	def set_InstanceIds(self,InstanceIds):
		self.add_query_param('InstanceIds',InstanceIds)

	def get_Status(self):
		return self.get_query_params().get('Status')

	def set_Status(self,Status):
		self.add_query_param('Status',Status)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeAlertLogListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeAlertLogList','cms')
		self.set_method('POST')

	def get_SendStatus(self):
		return self.get_query_params().get('SendStatus')

	def set_SendStatus(self,SendStatus):
		self.add_query_param('SendStatus',SendStatus)

	def get_ContactGroup(self):
		return self.get_query_params().get('ContactGroup')

	def set_ContactGroup(self,ContactGroup):
		self.add_query_param('ContactGroup',ContactGroup)

	def get_SearchKey(self):
		return self.get_query_params().get('SearchKey')

	def set_SearchKey(self,SearchKey):
		self.add_query_param('SearchKey',SearchKey)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_StartTime(self):
		return self.get_query_params().get('StartTime')

	def set_StartTime(self,StartTime):
		self.add_query_param('StartTime',StartTime)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_LastMin(self):
		return self.get_query_params().get('LastMin')

	def set_LastMin(self,LastMin):
		self.add_query_param('LastMin',LastMin)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)

	def get_Product(self):
		return self.get_query_params().get('Product')

	def set_Product(self,Product):
		self.add_query_param('Product',Product)

	def get_Level(self):
		return self.get_query_params().get('Level')

	def set_Level(self,Level):
		self.add_query_param('Level',Level)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_EndTime(self):
		return self.get_query_params().get('EndTime')

	def set_EndTime(self,EndTime):
		self.add_query_param('EndTime',EndTime)

	def get_GroupBy(self):
		return self.get_query_params().get('GroupBy')

	def set_GroupBy(self,GroupBy):
		self.add_query_param('GroupBy',GroupBy)

	def get_Namespace(self):
		return self.get_query_params().get('Namespace')

	def set_Namespace(self,Namespace):
		self.add_query_param('Namespace',Namespace)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class CreateCmsOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'CreateCmsOrder','cms')
		self.set_method('POST')

	def get_SmsCount(self):
		return self.get_query_params().get('SmsCount')

	def set_SmsCount(self,SmsCount):
		self.add_query_param('SmsCount',SmsCount)

	def get_AutoUseCoupon(self):
		return self.get_query_params().get('AutoUseCoupon')

	def set_AutoUseCoupon(self,AutoUseCoupon):
		self.add_query_param('AutoUseCoupon',AutoUseCoupon)

	def get_LogMonitorStream(self):
		return self.get_query_params().get('LogMonitorStream')

	def set_LogMonitorStream(self,LogMonitorStream):
		self.add_query_param('LogMonitorStream',LogMonitorStream)

	def get_CustomTimeSeries(self):
		return self.get_query_params().get('CustomTimeSeries')

	def set_CustomTimeSeries(self,CustomTimeSeries):
		self.add_query_param('CustomTimeSeries',CustomTimeSeries)

	def get_ApiCount(self):
		return self.get_query_params().get('ApiCount')

	def set_ApiCount(self,ApiCount):
		self.add_query_param('ApiCount',ApiCount)

	def get_PhoneCount(self):
		return self.get_query_params().get('PhoneCount')

	def set_PhoneCount(self,PhoneCount):
		self.add_query_param('PhoneCount',PhoneCount)

	def get_AutoRenewPeriod(self):
		return self.get_query_params().get('AutoRenewPeriod')

	def set_AutoRenewPeriod(self,AutoRenewPeriod):
		self.add_query_param('AutoRenewPeriod',AutoRenewPeriod)

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_AutoPay(self):
		return self.get_query_params().get('AutoPay')

	def set_AutoPay(self,AutoPay):
		self.add_query_param('AutoPay',AutoPay)

	def get_SuggestType(self):
		return self.get_query_params().get('SuggestType')

	def set_SuggestType(self,SuggestType):
		self.add_query_param('SuggestType',SuggestType)

	def get_EventStoreNum(self):
		return self.get_query_params().get('EventStoreNum')

	def set_EventStoreNum(self,EventStoreNum):
		self.add_query_param('EventStoreNum',EventStoreNum)

	def get_SiteTaskNum(self):
		return self.get_query_params().get('SiteTaskNum')

	def set_SiteTaskNum(self,SiteTaskNum):
		self.add_query_param('SiteTaskNum',SiteTaskNum)

	def get_PeriodUnit(self):
		return self.get_query_params().get('PeriodUnit')

	def set_PeriodUnit(self,PeriodUnit):
		self.add_query_param('PeriodUnit',PeriodUnit)

	def get_SiteOperatorNum(self):
		return self.get_query_params().get('SiteOperatorNum')

	def set_SiteOperatorNum(self,SiteOperatorNum):
		self.add_query_param('SiteOperatorNum',SiteOperatorNum)

	def get_SiteEcsNum(self):
		return self.get_query_params().get('SiteEcsNum')

	def set_SiteEcsNum(self,SiteEcsNum):
		self.add_query_param('SiteEcsNum',SiteEcsNum)

	def get_EventStoreTime(self):
		return self.get_query_params().get('EventStoreTime')

	def set_EventStoreTime(self,EventStoreTime):
		self.add_query_param('EventStoreTime',EventStoreTime)

	def get_PayType(self):
		return self.get_query_params().get('PayType')

	def set_PayType(self,PayType):
		self.add_query_param('PayType',PayType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutEventRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutEventRule','cms')
		self.set_method('POST')

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_Description(self):
		return self.get_query_params().get('Description')

	def set_Description(self,Description):
		self.add_query_param('Description',Description)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_EventPatterns(self):
		return self.get_query_params().get('EventPattern')

	def set_EventPatterns(self, EventPatterns):
		for depth1 in range(len(EventPatterns)):
			if EventPatterns[depth1].get('LevelList') is not None:
				for depth2 in range(len(EventPatterns[depth1].get('LevelList'))):
					if EventPatterns[depth1].get('LevelList')[depth2] is not None:
						self.add_query_param('EventPattern.' + str(depth1 + 1) + '.LevelList.' + str(depth2 + 1) , EventPatterns[depth1].get('LevelList')[depth2])
			if EventPatterns[depth1].get('KeywordFilter') is not None:
				self.add_query_param('EventPattern.' + str(depth1 + 1) + '.KeywordFilter', EventPatterns[depth1].get('KeywordFilter'))
			if EventPatterns[depth1].get('Product') is not None:
				self.add_query_param('EventPattern.' + str(depth1 + 1) + '.Product', EventPatterns[depth1].get('Product'))
			if EventPatterns[depth1].get('StatusList') is not None:
				for depth2 in range(len(EventPatterns[depth1].get('StatusList'))):
					if EventPatterns[depth1].get('StatusList')[depth2] is not None:
						self.add_query_param('EventPattern.' + str(depth1 + 1) + '.StatusList.' + str(depth2 + 1) , EventPatterns[depth1].get('StatusList')[depth2])
			if EventPatterns[depth1].get('NameList') is not None:
				for depth2 in range(len(EventPatterns[depth1].get('NameList'))):
					if EventPatterns[depth1].get('NameList')[depth2] is not None:
						self.add_query_param('EventPattern.' + str(depth1 + 1) + '.NameList.' + str(depth2 + 1) , EventPatterns[depth1].get('NameList')[depth2])
			if EventPatterns[depth1].get('EventTypeList') is not None:
				for depth2 in range(len(EventPatterns[depth1].get('EventTypeList'))):
					if EventPatterns[depth1].get('EventTypeList')[depth2] is not None:
						self.add_query_param('EventPattern.' + str(depth1 + 1) + '.EventTypeList.' + str(depth2 + 1) , EventPatterns[depth1].get('EventTypeList')[depth2])

	def get_EventType(self):
		return self.get_query_params().get('EventType')

	def set_EventType(self,EventType):
		self.add_query_param('EventType',EventType)

	def get_State(self):
		return self.get_query_params().get('State')

	def set_State(self,State):
		self.add_query_param('State',State)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutResourceMetricRulesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutResourceMetricRules','cms')
		self.set_method('POST')

	def get_Ruless(self):
		return self.get_query_params().get('Rules')

	def set_Ruless(self, Ruless):
		for depth1 in range(len(Ruless)):
			if Ruless[depth1].get('Webhook') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Webhook', Ruless[depth1].get('Webhook'))
			if Ruless[depth1].get('Escalations.Warn.ComparisonOperator') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Warn.ComparisonOperator', Ruless[depth1].get('Escalations.Warn.ComparisonOperator'))
			if Ruless[depth1].get('RuleName') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.RuleName', Ruless[depth1].get('RuleName'))
			if Ruless[depth1].get('Escalations.Info.Statistics') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Info.Statistics', Ruless[depth1].get('Escalations.Info.Statistics'))
			if Ruless[depth1].get('EffectiveInterval') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.EffectiveInterval', Ruless[depth1].get('EffectiveInterval'))
			if Ruless[depth1].get('Escalations.Info.ComparisonOperator') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Info.ComparisonOperator', Ruless[depth1].get('Escalations.Info.ComparisonOperator'))
			if Ruless[depth1].get('NoDataPolicy') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.NoDataPolicy', Ruless[depth1].get('NoDataPolicy'))
			if Ruless[depth1].get('NoEffectiveInterval') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.NoEffectiveInterval', Ruless[depth1].get('NoEffectiveInterval'))
			if Ruless[depth1].get('EmailSubject') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.EmailSubject', Ruless[depth1].get('EmailSubject'))
			if Ruless[depth1].get('SilenceTime') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.SilenceTime', Ruless[depth1].get('SilenceTime'))
			if Ruless[depth1].get('MetricName') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.MetricName', Ruless[depth1].get('MetricName'))
			if Ruless[depth1].get('Escalations.Warn.Times') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Warn.Times', Ruless[depth1].get('Escalations.Warn.Times'))
			if Ruless[depth1].get('CompositeExpression') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.CompositeExpression', Ruless[depth1].get('CompositeExpression'))
			if Ruless[depth1].get('Escalations.Warn.Threshold') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Warn.Threshold', Ruless[depth1].get('Escalations.Warn.Threshold'))
			if Ruless[depth1].get('Period') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Period', Ruless[depth1].get('Period'))
			if Ruless[depth1].get('ContactGroups') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.ContactGroups', Ruless[depth1].get('ContactGroups'))
			if Ruless[depth1].get('Escalations.Critical.Statistics') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Critical.Statistics', Ruless[depth1].get('Escalations.Critical.Statistics'))
			if Ruless[depth1].get('GroupId') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.GroupId', Ruless[depth1].get('GroupId'))
			if Ruless[depth1].get('Escalations.Info.Times') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Info.Times', Ruless[depth1].get('Escalations.Info.Times'))
			if Ruless[depth1].get('Resources') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Resources', Ruless[depth1].get('Resources'))
			if Ruless[depth1].get('Escalations.Critical.Times') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Critical.Times', Ruless[depth1].get('Escalations.Critical.Times'))
			if Ruless[depth1].get('Escalations.Info.Threshold') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Info.Threshold', Ruless[depth1].get('Escalations.Info.Threshold'))
			if Ruless[depth1].get('Escalations.Warn.Statistics') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Warn.Statistics', Ruless[depth1].get('Escalations.Warn.Statistics'))
			if Ruless[depth1].get('Namespace') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Namespace', Ruless[depth1].get('Namespace'))
			if Ruless[depth1].get('Interval') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Interval', Ruless[depth1].get('Interval'))
			if Ruless[depth1].get('RuleId') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.RuleId', Ruless[depth1].get('RuleId'))
			if Ruless[depth1].get('Escalations.Critical.ComparisonOperator') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Critical.ComparisonOperator', Ruless[depth1].get('Escalations.Critical.ComparisonOperator'))
			if Ruless[depth1].get('Escalations.Critical.Threshold') is not None:
				self.add_query_param('Rules.' + str(depth1 + 1) + '.Escalations.Critical.Threshold', Ruless[depth1].get('Escalations.Critical.Threshold'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class ModifyHostAvailabilityRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'ModifyHostAvailability','cms')
		self.set_method('POST')

	def get_TaskOptionHttpMethod(self):
		return self.get_query_params().get('TaskOption.HttpMethod')

	def set_TaskOptionHttpMethod(self,TaskOptionHttpMethod):
		self.add_query_param('TaskOption.HttpMethod',TaskOptionHttpMethod)

	def get_TaskOptionHttpHeader(self):
		return self.get_query_params().get('TaskOption.HttpHeader')

	def set_TaskOptionHttpHeader(self,TaskOptionHttpHeader):
		self.add_query_param('TaskOption.HttpHeader',TaskOptionHttpHeader)

	def get_AlertConfigEscalationLists(self):
		return self.get_query_params().get('AlertConfigEscalationList')

	def set_AlertConfigEscalationLists(self, AlertConfigEscalationLists):
		for depth1 in range(len(AlertConfigEscalationLists)):
			if AlertConfigEscalationLists[depth1].get('Times') is not None:
				self.add_query_param('AlertConfigEscalationList.' + str(depth1 + 1) + '.Times', AlertConfigEscalationLists[depth1].get('Times'))
			if AlertConfigEscalationLists[depth1].get('MetricName') is not None:
				self.add_query_param('AlertConfigEscalationList.' + str(depth1 + 1) + '.MetricName', AlertConfigEscalationLists[depth1].get('MetricName'))
			if AlertConfigEscalationLists[depth1].get('Value') is not None:
				self.add_query_param('AlertConfigEscalationList.' + str(depth1 + 1) + '.Value', AlertConfigEscalationLists[depth1].get('Value'))
			if AlertConfigEscalationLists[depth1].get('Operator') is not None:
				self.add_query_param('AlertConfigEscalationList.' + str(depth1 + 1) + '.Operator', AlertConfigEscalationLists[depth1].get('Operator'))
			if AlertConfigEscalationLists[depth1].get('Aggregate') is not None:
				self.add_query_param('AlertConfigEscalationList.' + str(depth1 + 1) + '.Aggregate', AlertConfigEscalationLists[depth1].get('Aggregate'))

	def get_TaskName(self):
		return self.get_query_params().get('TaskName')

	def set_TaskName(self,TaskName):
		self.add_query_param('TaskName',TaskName)

	def get_AlertConfigSilenceTime(self):
		return self.get_query_params().get('AlertConfig.SilenceTime')

	def set_AlertConfigSilenceTime(self,AlertConfigSilenceTime):
		self.add_query_param('AlertConfig.SilenceTime',AlertConfigSilenceTime)

	def get_TaskOptionHttpResponseCharset(self):
		return self.get_query_params().get('TaskOption.HttpResponseCharset')

	def set_TaskOptionHttpResponseCharset(self,TaskOptionHttpResponseCharset):
		self.add_query_param('TaskOption.HttpResponseCharset',TaskOptionHttpResponseCharset)

	def get_TaskOptionHttpNegative(self):
		return self.get_query_params().get('TaskOption.HttpNegative')

	def set_TaskOptionHttpNegative(self,TaskOptionHttpNegative):
		self.add_query_param('TaskOption.HttpNegative',TaskOptionHttpNegative)

	def get_TaskOptionInterval(self):
		return self.get_query_params().get('TaskOption.Interval')

	def set_TaskOptionInterval(self,TaskOptionInterval):
		self.add_query_param('TaskOption.Interval',TaskOptionInterval)

	def get_AlertConfigNotifyType(self):
		return self.get_query_params().get('AlertConfig.NotifyType')

	def set_AlertConfigNotifyType(self,AlertConfigNotifyType):
		self.add_query_param('AlertConfig.NotifyType',AlertConfigNotifyType)

	def get_TaskOptionTelnetOrPingHost(self):
		return self.get_query_params().get('TaskOption.TelnetOrPingHost')

	def set_TaskOptionTelnetOrPingHost(self,TaskOptionTelnetOrPingHost):
		self.add_query_param('TaskOption.TelnetOrPingHost',TaskOptionTelnetOrPingHost)

	def get_TaskOptionHttpResponseMatchContent(self):
		return self.get_query_params().get('TaskOption.HttpResponseMatchContent')

	def set_TaskOptionHttpResponseMatchContent(self,TaskOptionHttpResponseMatchContent):
		self.add_query_param('TaskOption.HttpResponseMatchContent',TaskOptionHttpResponseMatchContent)

	def get_Id(self):
		return self.get_query_params().get('Id')

	def set_Id(self,Id):
		self.add_query_param('Id',Id)

	def get_InstanceLists(self):
		return self.get_query_params().get('InstanceList')

	def set_InstanceLists(self, InstanceLists):
		for depth1 in range(len(InstanceLists)):
			if InstanceLists[depth1] is not None:
				self.add_query_param('InstanceList.' + str(depth1 + 1) , InstanceLists[depth1])

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_AlertConfigEndTime(self):
		return self.get_query_params().get('AlertConfig.EndTime')

	def set_AlertConfigEndTime(self,AlertConfigEndTime):
		self.add_query_param('AlertConfig.EndTime',AlertConfigEndTime)

	def get_TaskOptionHttpURI(self):
		return self.get_query_params().get('TaskOption.HttpURI')

	def set_TaskOptionHttpURI(self,TaskOptionHttpURI):
		self.add_query_param('TaskOption.HttpURI',TaskOptionHttpURI)

	def get_TaskScope(self):
		return self.get_query_params().get('TaskScope')

	def set_TaskScope(self,TaskScope):
		self.add_query_param('TaskScope',TaskScope)

	def get_TaskOptionHttpPostContent(self):
		return self.get_query_params().get('TaskOption.HttpPostContent')

	def set_TaskOptionHttpPostContent(self,TaskOptionHttpPostContent):
		self.add_query_param('TaskOption.HttpPostContent',TaskOptionHttpPostContent)

	def get_AlertConfigStartTime(self):
		return self.get_query_params().get('AlertConfig.StartTime')

	def set_AlertConfigStartTime(self,AlertConfigStartTime):
		self.add_query_param('AlertConfig.StartTime',AlertConfigStartTime)

	def get_AlertConfigWebHook(self):
		return self.get_query_params().get('AlertConfig.WebHook')

	def set_AlertConfigWebHook(self,AlertConfigWebHook):
		self.add_query_param('AlertConfig.WebHook',AlertConfigWebHook)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutExporterRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutExporterRule','cms')
		self.set_method('POST')

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_DstNamess(self):
		return self.get_query_params().get('DstNames')

	def set_DstNamess(self, DstNamess):
		for depth1 in range(len(DstNamess)):
			if DstNamess[depth1] is not None:
				self.add_query_param('DstNames.' + str(depth1 + 1) , DstNamess[depth1])

	def get_Namespace(self):
		return self.get_query_params().get('Namespace')

	def set_Namespace(self,Namespace):
		self.add_query_param('Namespace',Namespace)

	def get_TargetWindows(self):
		return self.get_query_params().get('TargetWindows')

	def set_TargetWindows(self,TargetWindows):
		self.add_query_param('TargetWindows',TargetWindows)

	def get_Describe(self):
		return self.get_query_params().get('Describe')

	def set_Describe(self,Describe):
		self.add_query_param('Describe',Describe)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutCustomEventRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutCustomEventRule','cms')
		self.set_method('POST')

	def get_Webhook(self):
		return self.get_query_params().get('Webhook')

	def set_Webhook(self,Webhook):
		self.add_query_param('Webhook',Webhook)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_Threshold(self):
		return self.get_query_params().get('Threshold')

	def set_Threshold(self,Threshold):
		self.add_query_param('Threshold',Threshold)

	def get_EffectiveInterval(self):
		return self.get_query_params().get('EffectiveInterval')

	def set_EffectiveInterval(self,EffectiveInterval):
		self.add_query_param('EffectiveInterval',EffectiveInterval)

	def get_EventName(self):
		return self.get_query_params().get('EventName')

	def set_EventName(self,EventName):
		self.add_query_param('EventName',EventName)

	def get_EmailSubject(self):
		return self.get_query_params().get('EmailSubject')

	def set_EmailSubject(self,EmailSubject):
		self.add_query_param('EmailSubject',EmailSubject)

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_ContactGroups(self):
		return self.get_query_params().get('ContactGroups')

	def set_ContactGroups(self,ContactGroups):
		self.add_query_param('ContactGroups',ContactGroups)

	def get_Level(self):
		return self.get_query_params().get('Level')

	def set_Level(self,Level):
		self.add_query_param('Level',Level)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_RuleId(self):
		return self.get_query_params().get('RuleId')

	def set_RuleId(self,RuleId):
		self.add_query_param('RuleId',RuleId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeMonitorGroupsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMonitorGroups','cms')
		self.set_method('POST')

	def get_SelectContactGroups(self):
		return self.get_query_params().get('SelectContactGroups')

	def set_SelectContactGroups(self,SelectContactGroups):
		self.add_query_param('SelectContactGroups',SelectContactGroups)

	def get_IncludeTemplateHistory(self):
		return self.get_query_params().get('IncludeTemplateHistory')

	def set_IncludeTemplateHistory(self,IncludeTemplateHistory):
		self.add_query_param('IncludeTemplateHistory',IncludeTemplateHistory)

	def get_DynamicTagRuleId(self):
		return self.get_query_params().get('DynamicTagRuleId')

	def set_DynamicTagRuleId(self,DynamicTagRuleId):
		self.add_query_param('DynamicTagRuleId',DynamicTagRuleId)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

	def get_PageNumber(self):
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_query_param('PageNumber',PageNumber)

	def get_GroupFounderTagKey(self):
		return self.get_query_params().get('GroupFounderTagKey')

	def set_GroupFounderTagKey(self,GroupFounderTagKey):
		self.add_query_param('GroupFounderTagKey',GroupFounderTagKey)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_Tags(self):
		return self.get_query_params().get('Tag')

	def set_Tags(self, Tags):
		for depth1 in range(len(Tags)):
			if Tags[depth1].get('Value') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
			if Tags[depth1].get('Key') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))

	def get_GroupFounderTagValue(self):
		return self.get_query_params().get('GroupFounderTagValue')

	def set_GroupFounderTagValue(self,GroupFounderTagValue):
		self.add_query_param('GroupFounderTagValue',GroupFounderTagValue)

	def get_Keyword(self):
		return self.get_query_params().get('Keyword')

	def set_Keyword(self,Keyword):
		self.add_query_param('Keyword',Keyword)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_GroupName(self):
		return self.get_query_params().get('GroupName')

	def set_GroupName(self,GroupName):
		self.add_query_param('GroupName',GroupName)

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutEventRuleTargetsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutEventRuleTargets','cms')
		self.set_method('POST')

	def get_WebhookParameterss(self):
		return self.get_query_params().get('WebhookParameters')

	def set_WebhookParameterss(self, WebhookParameterss):
		for depth1 in range(len(WebhookParameterss)):
			if WebhookParameterss[depth1].get('Protocol') is not None:
				self.add_query_param('WebhookParameters.' + str(depth1 + 1) + '.Protocol', WebhookParameterss[depth1].get('Protocol'))
			if WebhookParameterss[depth1].get('Method') is not None:
				self.add_query_param('WebhookParameters.' + str(depth1 + 1) + '.Method', WebhookParameterss[depth1].get('Method'))
			if WebhookParameterss[depth1].get('Id') is not None:
				self.add_query_param('WebhookParameters.' + str(depth1 + 1) + '.Id', WebhookParameterss[depth1].get('Id'))
			if WebhookParameterss[depth1].get('Url') is not None:
				self.add_query_param('WebhookParameters.' + str(depth1 + 1) + '.Url', WebhookParameterss[depth1].get('Url'))

	def get_ContactParameterss(self):
		return self.get_query_params().get('ContactParameters')

	def set_ContactParameterss(self, ContactParameterss):
		for depth1 in range(len(ContactParameterss)):
			if ContactParameterss[depth1].get('Level') is not None:
				self.add_query_param('ContactParameters.' + str(depth1 + 1) + '.Level', ContactParameterss[depth1].get('Level'))
			if ContactParameterss[depth1].get('Id') is not None:
				self.add_query_param('ContactParameters.' + str(depth1 + 1) + '.Id', ContactParameterss[depth1].get('Id'))
			if ContactParameterss[depth1].get('ContactGroupName') is not None:
				self.add_query_param('ContactParameters.' + str(depth1 + 1) + '.ContactGroupName', ContactParameterss[depth1].get('ContactGroupName'))

	def get_SlsParameterss(self):
		return self.get_query_params().get('SlsParameters')

	def set_SlsParameterss(self, SlsParameterss):
		for depth1 in range(len(SlsParameterss)):
			if SlsParameterss[depth1].get('Project') is not None:
				self.add_query_param('SlsParameters.' + str(depth1 + 1) + '.Project', SlsParameterss[depth1].get('Project'))
			if SlsParameterss[depth1].get('Id') is not None:
				self.add_query_param('SlsParameters.' + str(depth1 + 1) + '.Id', SlsParameterss[depth1].get('Id'))
			if SlsParameterss[depth1].get('Region') is not None:
				self.add_query_param('SlsParameters.' + str(depth1 + 1) + '.Region', SlsParameterss[depth1].get('Region'))
			if SlsParameterss[depth1].get('LogStore') is not None:
				self.add_query_param('SlsParameters.' + str(depth1 + 1) + '.LogStore', SlsParameterss[depth1].get('LogStore'))

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_MnsParameterss(self):
		return self.get_query_params().get('MnsParameters')

	def set_MnsParameterss(self, MnsParameterss):
		for depth1 in range(len(MnsParameterss)):
			if MnsParameterss[depth1].get('Id') is not None:
				self.add_query_param('MnsParameters.' + str(depth1 + 1) + '.Id', MnsParameterss[depth1].get('Id'))
			if MnsParameterss[depth1].get('Region') is not None:
				self.add_query_param('MnsParameters.' + str(depth1 + 1) + '.Region', MnsParameterss[depth1].get('Region'))
			if MnsParameterss[depth1].get('Queue') is not None:
				self.add_query_param('MnsParameters.' + str(depth1 + 1) + '.Queue', MnsParameterss[depth1].get('Queue'))

	def get_FcParameterss(self):
		return self.get_query_params().get('FcParameters')

	def set_FcParameterss(self, FcParameterss):
		for depth1 in range(len(FcParameterss)):
			if FcParameterss[depth1].get('FunctionName') is not None:
				self.add_query_param('FcParameters.' + str(depth1 + 1) + '.FunctionName', FcParameterss[depth1].get('FunctionName'))
			if FcParameterss[depth1].get('ServiceName') is not None:
				self.add_query_param('FcParameters.' + str(depth1 + 1) + '.ServiceName', FcParameterss[depth1].get('ServiceName'))
			if FcParameterss[depth1].get('Id') is not None:
				self.add_query_param('FcParameters.' + str(depth1 + 1) + '.Id', FcParameterss[depth1].get('Id'))
			if FcParameterss[depth1].get('Region') is not None:
				self.add_query_param('FcParameters.' + str(depth1 + 1) + '.Region', FcParameterss[depth1].get('Region'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutResourceMetricRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'PutResourceMetricRule','cms')
		self.set_method('POST')

	def get_Webhook(self):
		return self.get_query_params().get('Webhook')

	def set_Webhook(self,Webhook):
		self.add_query_param('Webhook',Webhook)

	def get_EscalationsWarnComparisonOperator(self):
		return self.get_query_params().get('Escalations.Warn.ComparisonOperator')

	def set_EscalationsWarnComparisonOperator(self,EscalationsWarnComparisonOperator):
		self.add_query_param('Escalations.Warn.ComparisonOperator',EscalationsWarnComparisonOperator)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_EffectiveInterval(self):
		return self.get_query_params().get('EffectiveInterval')

	def set_EffectiveInterval(self,EffectiveInterval):
		self.add_query_param('EffectiveInterval',EffectiveInterval)

	def get_NoDataPolicy(self):
		return self.get_query_params().get('NoDataPolicy')

	def set_NoDataPolicy(self,NoDataPolicy):
		self.add_query_param('NoDataPolicy',NoDataPolicy)

	def get_NoEffectiveInterval(self):
		return self.get_query_params().get('NoEffectiveInterval')

	def set_NoEffectiveInterval(self,NoEffectiveInterval):
		self.add_query_param('NoEffectiveInterval',NoEffectiveInterval)

	def get_EmailSubject(self):
		return self.get_query_params().get('EmailSubject')

	def set_EmailSubject(self,EmailSubject):
		self.add_query_param('EmailSubject',EmailSubject)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)

	def get_EscalationsWarnTimes(self):
		return self.get_query_params().get('Escalations.Warn.Times')

	def set_EscalationsWarnTimes(self,EscalationsWarnTimes):
		self.add_query_param('Escalations.Warn.Times',EscalationsWarnTimes)

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_EscalationsWarnThreshold(self):
		return self.get_query_params().get('Escalations.Warn.Threshold')

	def set_EscalationsWarnThreshold(self,EscalationsWarnThreshold):
		self.add_query_param('Escalations.Warn.Threshold',EscalationsWarnThreshold)

	def get_ContactGroups(self):
		return self.get_query_params().get('ContactGroups')

	def set_ContactGroups(self,ContactGroups):
		self.add_query_param('ContactGroups',ContactGroups)

	def get_EscalationsCriticalStatistics(self):
		return self.get_query_params().get('Escalations.Critical.Statistics')

	def set_EscalationsCriticalStatistics(self,EscalationsCriticalStatistics):
		self.add_query_param('Escalations.Critical.Statistics',EscalationsCriticalStatistics)

	def get_Labels(self):
		return self.get_query_params().get('Labels')

	def set_Labels(self,Labels):
		self.add_query_param('Labels',Labels)

	def get_Interval(self):
		return self.get_query_params().get('Interval')

	def set_Interval(self,Interval):
		self.add_query_param('Interval',Interval)

	def get_RuleId(self):
		return self.get_query_params().get('RuleId')

	def set_RuleId(self,RuleId):
		self.add_query_param('RuleId',RuleId)

	def get_EscalationsCriticalThreshold(self):
		return self.get_query_params().get('Escalations.Critical.Threshold')

	def set_EscalationsCriticalThreshold(self,EscalationsCriticalThreshold):
		self.add_query_param('Escalations.Critical.Threshold',EscalationsCriticalThreshold)

	def get_EscalationsInfoStatistics(self):
		return self.get_query_params().get('Escalations.Info.Statistics')

	def set_EscalationsInfoStatistics(self,EscalationsInfoStatistics):
		self.add_query_param('Escalations.Info.Statistics',EscalationsInfoStatistics)

	def get_EscalationsInfoComparisonOperator(self):
		return self.get_query_params().get('Escalations.Info.ComparisonOperator')

	def set_EscalationsInfoComparisonOperator(self,EscalationsInfoComparisonOperator):
		self.add_query_param('Escalations.Info.ComparisonOperator',EscalationsInfoComparisonOperator)

	def get_SilenceTime(self):
		return self.get_query_params().get('SilenceTime')

	def set_SilenceTime(self,SilenceTime):
		self.add_query_param('SilenceTime',SilenceTime)

	def get_Resources(self):
		return self.get_query_params().get('Resources')

	def set_Resources(self,Resources):
		self.add_query_param('Resources',Resources)

	def get_EscalationsInfoTimes(self):
		return self.get_query_params().get('Escalations.Info.Times')

	def set_EscalationsInfoTimes(self,EscalationsInfoTimes):
		self.add_query_param('Escalations.Info.Times',EscalationsInfoTimes)

	def get_EscalationsCriticalTimes(self):
		return self.get_query_params().get('Escalations.Critical.Times')

	def set_EscalationsCriticalTimes(self,EscalationsCriticalTimes):
		self.add_query_param('Escalations.Critical.Times',EscalationsCriticalTimes)

	def get_EscalationsWarnStatistics(self):
		return self.get_query_params().get('Escalations.Warn.Statistics')

	def set_EscalationsWarnStatistics(self,EscalationsWarnStatistics):
		self.add_query_param('Escalations.Warn.Statistics',EscalationsWarnStatistics)

	def get_EscalationsInfoThreshold(self):
		return self.get_query_params().get('Escalations.Info.Threshold')

	def set_EscalationsInfoThreshold(self,EscalationsInfoThreshold):
		self.add_query_param('Escalations.Info.Threshold',EscalationsInfoThreshold)

	def get_Namespace(self):
		return self.get_query_params().get('Namespace')

	def set_Namespace(self,Namespace):
		self.add_query_param('Namespace',Namespace)

	def get_EscalationsCriticalComparisonOperator(self):
		return self.get_query_params().get('Escalations.Critical.ComparisonOperator')

	def set_EscalationsCriticalComparisonOperator(self,EscalationsCriticalComparisonOperator):
		self.add_query_param('Escalations.Critical.ComparisonOperator',EscalationsCriticalComparisonOperator)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class ModifyGroupMonitoringAgentProcessRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'ModifyGroupMonitoringAgentProcess','cms')
		self.set_method('POST')

	def get_AlertConfigs(self):
		return self.get_query_params().get('AlertConfig')

	def set_AlertConfigs(self, AlertConfigs):
		for depth1 in range(len(AlertConfigs)):
			if AlertConfigs[depth1].get('Times') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.Times', AlertConfigs[depth1].get('Times'))
			if AlertConfigs[depth1].get('NoEffectiveInterval') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.NoEffectiveInterval', AlertConfigs[depth1].get('NoEffectiveInterval'))
			if AlertConfigs[depth1].get('Webhook') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.Webhook', AlertConfigs[depth1].get('Webhook'))
			if AlertConfigs[depth1].get('SilenceTime') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.SilenceTime', AlertConfigs[depth1].get('SilenceTime'))
			if AlertConfigs[depth1].get('Threshold') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.Threshold', AlertConfigs[depth1].get('Threshold'))
			if AlertConfigs[depth1].get('EffectiveInterval') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.EffectiveInterval', AlertConfigs[depth1].get('EffectiveInterval'))
			if AlertConfigs[depth1].get('ComparisonOperator') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.ComparisonOperator', AlertConfigs[depth1].get('ComparisonOperator'))
			if AlertConfigs[depth1].get('EscalationsLevel') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.EscalationsLevel', AlertConfigs[depth1].get('EscalationsLevel'))
			if AlertConfigs[depth1].get('Statistics') is not None:
				self.add_query_param('AlertConfig.' + str(depth1 + 1) + '.Statistics', AlertConfigs[depth1].get('Statistics'))

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_MatchExpressFilterRelation(self):
		return self.get_query_params().get('MatchExpressFilterRelation')

	def set_MatchExpressFilterRelation(self,MatchExpressFilterRelation):
		self.add_query_param('MatchExpressFilterRelation',MatchExpressFilterRelation)

	def get_Id(self):
		return self.get_query_params().get('Id')

	def set_Id(self,Id):
		self.add_query_param('Id',Id)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeMetricRuleListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeMetricRuleList','cms')
		self.set_method('POST')

	def get_EnableState(self):
		return self.get_query_params().get('EnableState')

	def set_EnableState(self,EnableState):
		self.add_query_param('EnableState',EnableState)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_RuleIds(self):
		return self.get_query_params().get('RuleIds')

	def set_RuleIds(self,RuleIds):
		self.add_query_param('RuleIds',RuleIds)

	def get_Namespace(self):
		return self.get_query_params().get('Namespace')

	def set_Namespace(self,Namespace):
		self.add_query_param('Namespace',Namespace)

	def get_AlertState(self):
		return self.get_query_params().get('AlertState')

	def set_AlertState(self,AlertState):
		self.add_query_param('AlertState',AlertState)

	def get_Page(self):
		return self.get_query_params().get('Page')

	def set_Page(self,Page):
		self.add_query_param('Page',Page)

	def get_Dimensions(self):
		return self.get_query_params().get('Dimensions')

	def set_Dimensions(self,Dimensions):
		self.add_query_param('Dimensions',Dimensions)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeSiteMonitorDataRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DescribeSiteMonitorData','cms')
		self.set_method('POST')

	def get_Period(self):
		return self.get_query_params().get('Period')

	def set_Period(self,Period):
		self.add_query_param('Period',Period)

	def get_Length(self):
		return self.get_query_params().get('Length')

	def set_Length(self,Length):
		self.add_query_param('Length',Length)

	def get_EndTime(self):
		return self.get_query_params().get('EndTime')

	def set_EndTime(self,EndTime):
		self.add_query_param('EndTime',EndTime)

	def get_StartTime(self):
		return self.get_query_params().get('StartTime')

	def set_StartTime(self,StartTime):
		self.add_query_param('StartTime',StartTime)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

	def get_NextToken(self):
		return self.get_query_params().get('NextToken')

	def set_NextToken(self,NextToken):
		self.add_query_param('NextToken',NextToken)

	def get_MetricName(self):
		return self.get_query_params().get('MetricName')

	def set_MetricName(self,MetricName):
		self.add_query_param('MetricName',MetricName)

	def get_TaskId(self):
		return self.get_query_params().get('TaskId')

	def set_TaskId(self,TaskId):
		self.add_query_param('TaskId',TaskId)